@@ -14,7 +14,7 @@ import aws_cdk.aws_iam
 import aws_cdk.aws_kms
 import aws_cdk.aws_lambda
 import aws_cdk.aws_s3
-import aws_cdk.cdk
+import aws_cdk.core
 __all__ = []
 
 publication.publish()
